@@ -71,6 +71,11 @@
 #include <unistd.h>
 #include <config.h>
 
+/***
+ * Do not change the below format, it will be set correctly while packing the code
+ */
+#define BUILDTIME  " (built: Thu May  9 15:05:35 UTC 2019)"
+
 #define GlobalServerSessionHooks (LsiApiHooks::getServerSessionHooks())
 
 static char s_iRunning = 0;
@@ -82,6 +87,7 @@ LshttpdMain::LshttpdMain()
     , m_pBuilder(NULL)
     , m_noDaemon(0)
     , m_noCrashGuard(0)
+    , m_iConfTestMode(0)
     , m_pProcState(NULL)
     , m_curChildren(0)
     , m_fdAdmin(-1)
@@ -631,6 +637,10 @@ int LshttpdMain::config()
         m_pBuilder->releaseConfigXmlTree();
     if (ret != 0)
         return 1;
+    
+    if (m_iConfTestMode)
+        return 0;
+    
     if (m_pServer->isServerOk())
         return 2;
 //    if ( ServerProcessConfig::getInstance.getChroot != NULL )
@@ -715,13 +725,13 @@ int LshttpdMain::testRunningServer()
 
 void LshttpdMain::printVersion()
 {
-    printf("%s\n\tmodule versions:\n%s\n",
-           HttpServerVersion::getVersion(), LS_MODULE_VERSION_INFO);
+    printf("%s%s\n\tmodule versions:\n%s\n",
+           HttpServerVersion::getVersion(), BUILDTIME, LS_MODULE_VERSION_INFO);
 }
 
 void LshttpdMain::parseOpt(int argc, char *argv[])
 {
-    const char *opts = "cdnv";
+    const char *opts = "cdntv";
     int c;
     char achCwd[512];
     getServerRootFromExecutablePath(argv[0], achCwd, 512);
@@ -740,6 +750,11 @@ void LshttpdMain::parseOpt(int argc, char *argv[])
         case 'n':
             m_noDaemon = 1;
             break;
+        case 't':
+            m_noDaemon = 1;
+            m_noCrashGuard = 1;
+            m_iConfTestMode = 1;
+            break;
         case 'v':
             printVersion();
             exit(0);
@@ -806,6 +821,7 @@ int LshttpdMain::init(int argc, char *argv[])
     ServerProcessConfig &procConfig = ServerProcessConfig::getInstance();
     if (argc > 1)
         parseOpt(argc, argv);
+
     if (getServerRoot(argc, argv) != 0)
     {
         //LS_ERROR("Failed to determine the root directory of server!" ));
@@ -814,15 +830,22 @@ int LshttpdMain::init(int argc, char *argv[])
         return 1;
     }
 
-    mkdir(DEFAULT_TMP_DIR,  0755);
 
-    if (testRunningServer() != 0)
-        return 2;
+    if (!m_iConfTestMode)
+    {
+        mkdir(DEFAULT_TMP_DIR,  0755);
 
+        if (testRunningServer() != 0)
+            return 2;
+    }
+    else
+        MainServerConfig::getInstance().setConfTestMode(1);
+    
 #ifndef IS_LSCPD
 
     //load the config
     m_pBuilder->loadConfigFile();
+
 //    m_pBuilder->loadPlainConfigFile();
     if (m_pServer->configServerBasics(0, m_pBuilder->getRoot()))
         return 1;
@@ -855,9 +878,11 @@ int LshttpdMain::init(int argc, char *argv[])
     plainconf::flushErrorLog();
 #endif
 
-    LS_NOTICE("Loading %s ...", HttpServerVersion::getVersion());
+  
+    LS_NOTICE("Loading %s%s ...", HttpServerVersion::getVersion(), BUILDTIME);
     LS_NOTICE("Using [%s]", SSLeay_version(SSLEAY_VERSION));
 
+
     if (!m_noDaemon)
     {
         if (Daemonize::daemonize(1, 1))
@@ -868,29 +893,37 @@ int LshttpdMain::init(int argc, char *argv[])
 #endif
     }
 
-    enableCoreDump();
+    if (!m_iConfTestMode)
+    {
+        enableCoreDump();
+
+        if (testRunningServer() != 0)
+            return 2;
+        m_pid = getpid();
+        if (m_pidFile.writePid(m_pid))
+            return 2;
 
 
-    if (testRunningServer() != 0)
-        return 2;
-    m_pid = getpid();
-    if (m_pidFile.writePid(m_pid))
-        return 2;
-
-
-    if (!MainServerConfig::getInstance().getDisableWebAdmin())
-        startAdminSocket();
-    
+        if (!MainServerConfig::getInstance().getDisableWebAdmin())
+            startAdminSocket();
+    }
+        
 #ifndef IS_LSCPD
     ret = config();
-    if (ret)
+    if (ret && !m_iConfTestMode)
     {
         LS_ERROR("Fatal error in configuration, exit!");
         fprintf(stderr, "[ERROR] Fatal error in configuration, shutdown!\n");
         return ret;
     }
+
 #endif
 
+    if (m_iConfTestMode)
+    {
+        return 0;
+    }
+
     removeOldRtreport();
     {
         char achBuf[8192];
@@ -982,12 +1015,47 @@ int LshttpdMain::main(int argc, char *argv[])
         if (ret != 0)
             return ret;
 
-        m_pServer->start();
+        if (!m_iConfTestMode)
+        {
+            m_pServer->start();
 
-        //If HttpServerConfig::s_iProcNo is 0, is main process
-        if (GlobalServerSessionHooks->isEnabled(LSI_HKPT_WORKER_ATEXIT))
-            GlobalServerSessionHooks->runCallbackNoParam(LSI_HKPT_WORKER_ATEXIT, NULL);
+            //If HttpServerConfig::s_iProcNo is 0, is main process
+            if (GlobalServerSessionHooks->isEnabled(LSI_HKPT_WORKER_ATEXIT))
+                GlobalServerSessionHooks->runCallbackNoParam(LSI_HKPT_WORKER_ATEXIT, NULL);
+        }
         m_pServer->releaseAll();
+        
+        if (m_iConfTestMode)
+        {
+            int ret = 0;
+            int fd = ::open(TEST_CONF_LOG, O_RDONLY);
+            if (fd != -1)
+            {
+                struct stat st;
+                if (fstat(fd, &st) == 0 && st.st_size > 0)
+                {
+                    ret = 1;
+                    unsigned char *buff  = (unsigned char *)mmap((caddr_t)0,
+                                                                 st.st_size,
+                                                                 PROT_READ,
+                                                                 MAP_SHARED,
+                                                                 fd,
+                                                                 0);
+                    if (buff != (unsigned char *)(-1))
+                    {
+                        printf("%.*s", (int)st.st_size, buff);
+                        
+                        if (strstr((const char *)buff, "[ERROR]") != NULL)
+                            ret = 2;
+                    }
+                    munmap((caddr_t)buff, st.st_size);
+                }
+                
+                close(fd);
+                unlink(TEST_CONF_LOG);
+            }
+            return ret;
+        }
     }
     return 0;
 }
